﻿using System;
using System.Reflection;
using System.Windows.Forms;

namespace LANChatClient
{
    partial class AboutForm : Form
    {
        public AboutForm()
        {
            InitializeComponent();
            this.Text = String.Format("About {0}", AssemblyTitle);
            this.labelProductName.Text = "LANChat Client";
            this.labelVersion.Text = String.Format("Version {0}", AssemblyVersion);
            this.labelCopyright.Text = AssemblyCopyright;
            this.labelCompanyName.Text = AssemblyCompany;
            this.textBoxDescription.Text = AssemblyDescription;

            if (Properties.Settings.Default.Language == "en")
            {
                this.Text = ClientAboutFormStringsEnglish.WindowTitle;
                this.labelVersion.Text = String.Format(ClientAboutFormStringsEnglish.Version, AssemblyVersion);
                this.labelCopyright.Text = ClientAboutFormStringsEnglish.Copyright;
                this.labelCompanyName.Text = ClientAboutFormStringsEnglish.CompanyName;
                this.textBoxDescription.Text = ClientAboutFormStringsEnglish.Description;
            }
            else if (Properties.Settings.Default.Language == "de")
            {
                this.Text = ClientAboutFormStringsGerman.WindowTitle;
                this.labelVersion.Text = String.Format(ClientAboutFormStringsGerman.Version, AssemblyVersion);
                this.labelCopyright.Text = ClientAboutFormStringsGerman.Copyright;
                this.labelCompanyName.Text = ClientAboutFormStringsGerman.CompanyName;
                this.textBoxDescription.Text = ClientAboutFormStringsGerman.Description;
            }
            else
            {
                this.Text = ClientAboutFormStringsFrench.WindowTitle;
                this.labelVersion.Text = String.Format(ClientAboutFormStringsFrench.Version, AssemblyVersion);
                this.labelCopyright.Text = ClientAboutFormStringsFrench.Copyright;
                this.labelCompanyName.Text = ClientAboutFormStringsFrench.CompanyName;
                this.textBoxDescription.Text = ClientAboutFormStringsFrench.Description;
            }
        }

        #region Assembly Attribute Accessors

        public string AssemblyTitle
        {
            get
            {
                object[] attributes = Assembly.GetExecutingAssembly().GetCustomAttributes(typeof(AssemblyTitleAttribute), false);
                if (attributes.Length > 0)
                {
                    AssemblyTitleAttribute titleAttribute = (AssemblyTitleAttribute)attributes[0];
                    if (titleAttribute.Title != "")
                    {
                        return titleAttribute.Title;
                    }
                }
                return System.IO.Path.GetFileNameWithoutExtension(Assembly.GetExecutingAssembly().CodeBase);
            }
        }

        public string AssemblyVersion
        {
            get
            {
                return Assembly.GetExecutingAssembly().GetName().Version.ToString();
            }
        }

        public string AssemblyDescription
        {
            get
            {
                object[] attributes = Assembly.GetExecutingAssembly().GetCustomAttributes(typeof(AssemblyDescriptionAttribute), false);
                if (attributes.Length == 0)
                {
                    return "";
                }
                return ((AssemblyDescriptionAttribute)attributes[0]).Description;
            }
        }

        public string AssemblyProduct
        {
            get
            {
                object[] attributes = Assembly.GetExecutingAssembly().GetCustomAttributes(typeof(AssemblyProductAttribute), false);
                if (attributes.Length == 0)
                {
                    return "";
                }
                return ((AssemblyProductAttribute)attributes[0]).Product;
            }
        }

        public string AssemblyCopyright
        {
            get
            {
                object[] attributes = Assembly.GetExecutingAssembly().GetCustomAttributes(typeof(AssemblyCopyrightAttribute), false);
                if (attributes.Length == 0)
                {
                    return "";
                }
                return ((AssemblyCopyrightAttribute)attributes[0]).Copyright;
            }
        }

        public string AssemblyCompany
        {
            get
            {
                object[] attributes = Assembly.GetExecutingAssembly().GetCustomAttributes(typeof(AssemblyCompanyAttribute), false);
                if (attributes.Length == 0)
                {
                    return "";
                }
                return ((AssemblyCompanyAttribute)attributes[0]).Company;
            }
        }
        #endregion
    }
}
